==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-AOulmnMi8E3IGpOgjopXfv
key: prettyprinter-convert-ansi-wl-pprint-1.1-AOulmnMi8E3IGpOgjopXfv
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: 2cefdb006e3fcb7bff9d8754ba2f2d03
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-AOulmnMi8E3IGpOgjopXfv
depends:
    base-4.11.1.0 text-1.2.3.0
    prettyprinter-1.2.1-AQ7onoQgGnsFEEPn37paqa
    prettyprinter-ansi-terminal-1.1.1.2-3lPPr8ZXfzs1Rr7H19JK2K
    ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-AQ7onoQgGnsFEEPn37paqa=1f292ee3fe29317b46f5946763b487fb
             prettyprinter-ansi-terminal-1.1.1.2-3lPPr8ZXfzs1Rr7H19JK2K=41bd821cf238e035cf39bd30733c81ba
             ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl=9d4f369601ee2b22ce73b0afa89e8002
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-D7LJiuJ0zOBmIPl9I7JgV
key: prettyprinter-convert-ansi-wl-pprint-1.1-D7LJiuJ0zOBmIPl9I7JgV
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: a537ab419c238387f4b8f01e8499c59e
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-D7LJiuJ0zOBmIPl9I7JgV
depends:
    base-4.11.1.0 text-1.2.3.0
    prettyprinter-1.2.1-Ae4jcxBvY3JJIG554Hxv9y
    prettyprinter-ansi-terminal-1.1.1.2-LabFhfgegMJHzliVaLUWVl
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-Ae4jcxBvY3JJIG554Hxv9y=4bb33cc1efa5d78ab6fd5da88a16de65
             prettyprinter-ansi-terminal-1.1.1.2-LabFhfgegMJHzliVaLUWVl=2a42e27e8c62c59bd5162332566551b1
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
